# 🔒 Magic OAuth Extension for React Native

> With the Magic JavaScript SDK OAuth extension, you can plug into your favorite social login providers with one, easy-to-use API.

<p align="center">
  <a href="https://github.com/fortmatic/magic-sdk-extensions/blob/master/packages/extension-react-native-oauth/LICENSE">License</a> ·
  <a href="https://github.com/fortmatic/magic-sdk-extensions/blob/master/CONTRIBUTING.md">Contributing Guide</a>
</p>

## 📖 Documentation

See the [developer documentation](https://docs.magic.link/social-login) to learn how to get started with OAuth in Magic SDK.

## 🔗 Installation

Integrating your app with OAuth will require our React Native NPM package and OAuth extension:

```bash
# Via NPM:
npm install --save @magic-sdk/react-native @magic-ext/react-native-oauth

# Via Yarn:
yarn add @magic-sdk/react-native @magic-ext/react-native-oauth
```

## ⚡️ Quick Start

Sign up or log in to the [developer dashboard](https://dashboard.magic.link) to receive API keys that will allow your application to interact with Magic's authentication APIs.

Then, you can start authenticating users with _just one method!_

```tsx
import React from 'react';
import { Magic } from '@magic-sdk/react-native';
import { OAuthExtension } from '@magic-ext/react-native-oauth';

const magic = new Magic('YOUR_API_KEY', {
  extensions: [new OAuthExtension()]
});

export default function App() {
  return <>
    {/* Render the Magic iframe! */}
    <magic.Relayer />
    {...}
  </>
}

// Somewhere else in your code...
const res = await magic.oauth.loginWithPopup({
  provider: 'google' | 'facebook' | 'github' | ...
});

// Then you can access a user's Magic DID token, OAuth access token,
// OpenID Connect profile information, and more!
res.magic.idToken;
res.oauth.accessToken;
res.oauth.userInfo;
```
